<?php
/**
* Author:
* Michael Kefeder
*/

$labels = array();
$labels['label'] = 'Etiquetas do Thunderbird';
$labels['label0'] = 'Sem etiqueta';
$labels['label1'] = 'Importante';
$labels['label2'] = 'Trabalho';
$labels['label3'] = 'Pessoal';
$labels['label4'] = 'Fazer';
$labels['label5'] = 'Depois';

$labels['tb_label_options'] = 'Opções das Etiquetas do Thunderbird';
$labels['tb_label_enable_option'] = 'Habilitar etiquetas';
$labels['tb_label_enable_shortcuts_option'] = 'Habilitar atalhos de teclado';
$labels['tb_label_button_label'] = 'Etiquetas';
$labels['tb_label_button_title'] = 'Definir etiquenas nas mensagens';
$labels['tb_label_contextmenu_title'] = 'Etiquetas';
$labels['tb_label_style_option'] = "Estilo de UI para as etiquetas";
$labels['tb_label_label'] = "Etiqueta";

$messages = array();
