<?php
/**
* Author:
* Artem Ushakov
*/

$labels = array();
$labels['label'] = 'Vēstules atzīme';
$labels['label0'] = 'Izdzēst visas atzīmes';
$labels['label1'] = 'Svarīgs';
$labels['label2'] = 'Darba';
$labels['label3'] = 'Personāls';
$labels['label4'] = 'Izpildei';
$labels['label5'] = 'Atlikts';

$messages = array();
