<?php
/**
* Author:
* radi_sh
*/

$labels = array();
$labels['label'] = 'Thunderbird ラベル';
$labels['label0'] = '全てのラベルを削除';
$labels['label1'] = '重要';
$labels['label2'] = '仕事';
$labels['label3'] = 'プライベート';
$labels['label4'] = 'To do';
$labels['label5'] = '後で';

$labels['tb_label_options'] = 'Thunderbird ラベル オプション';
$labels['tb_label_enable_option'] = 'ラベルを有効にする';
$labels['tb_label_enable_shortcuts_option'] = 'キーボードショートカットを有効にする';
$labels['tb_label_button_label'] = 'ラベル';
$labels['tb_label_button_title'] = 'メッセージにラベルを付ける';
$labels['tb_label_contextmenu_title'] = 'ラベル';
$labels['tb_label_style_option'] = "ラベルのUIスタイル";
$labels['tb_label_label'] = "ラベル";

$messages = array();

