<?php
/**
* Author:
* Michael Kefeder
*/

$labels = array();
$labels['label'] = 'Thunderbird Labels';
$labels['label0'] = 'No Label';
$labels['label1'] = 'Important';
$labels['label2'] = 'Work';
$labels['label3'] = 'Personal';
$labels['label4'] = 'To do';
$labels['label5'] = 'Later';

$labels['tb_label_options'] = 'Thunderbird Labels Options';
$labels['tb_label_enable_option'] = 'Enable labels';
$labels['tb_label_enable_shortcuts_option'] = 'Enable keyboard shortcuts';
$labels['tb_label_button_label'] = 'Labels';
$labels['tb_label_button_title'] = 'Set labels on messages';
$labels['tb_label_contextmenu_title'] = 'Labels';
$labels['tb_label_style_option'] = "UI Style for labels";
$labels['tb_label_label'] = "Label";

$messages = array();

