<?php
/**
* Author:
* Tobias Geerinckx-Rice
*/

$labels = array();
$labels['label'] = 'Thunderbird-etiketten';
$labels['label0'] = 'Geen etiket';
$labels['label1'] = 'Belangrijk';
$labels['label2'] = 'Werk';
$labels['label3'] = 'Persoonlijk';
$labels['label4'] = 'Te doen';
$labels['label5'] = 'Later';

$labels['tb_label_options'] = 'Thunderbird-etiketten';
$labels['tb_label_enable_option'] = 'Thunderbird-etiketten tonen en beheren';
$labels['tb_label_enable_shortcuts_option'] = 'Sneltoetsen voor etiketteren';
$labels['tb_label_button_label'] = 'Etiketten';
$labels['tb_label_button_title'] = 'Etiketteer berichten';
$labels['tb_label_contextmenu_title'] = 'Etiketten';
$labels['tb_label_style_option'] = "Weergavestijl van etiketten";
$labels['tb_label_label'] = "Etiket";

$messages = array();
