<?php
/*
 +-----------------------------------------------------------------------+
| Localization file of the Roundcube Thunderbird Labels plugin          |
| Copyright (C) 2013, JPL TSolucio, S.L. (Joe Bordes)                   |
|                                                                       |
| Licensed under the GNU General Public License version 3 or            |
| any later version.                                                    |
|                                                                       |
+-----------------------------------------------------------------------+
*/

$labels = array();
$labels['label'] = 'Etiquetas Thunderbird';
$labels['label0'] = 'Eliminar Etiquetas';
$labels['label1'] = 'Importante';
$labels['label2'] = 'Trabajo';
$labels['label3'] = 'Personal';
$labels['label4'] = 'Por Hacer';
$labels['label5'] = 'Más Tarde';

$labels['tb_label_options'] = 'Configuración Etiquetas Thunderbird';
$labels['tb_label_enable_option'] = 'Activar Etiquetas';
$labels['tb_label_enable_shortcuts_option'] = 'Activar atajos de teclado';
$labels['tb_label_button_label'] = 'Etiquetas';
$labels['tb_label_button_title'] = 'Establecer etiquetas sobre mensajes';
$labels['tb_label_contextmenu_title'] = 'Etiquetas';
$labels['tb_label_style_option'] = "Presentación de etiquetas";
$labels['tb_label_label'] = "Etiqueta";

$messages = array();

