<?php
/**
* Author:
* Michael Kefeder
*/

$labels = array();
$labels['label'] = 'Thunderbird Schlagwörter';
$labels['label0'] = 'Alle Entfernen';
$labels['label1'] = 'Wichtig';
$labels['label2'] = 'Dienstlich';
$labels['label3'] = 'Persönlich'; // grün
$labels['label4'] = 'Zu Erledigen'; // blau
$labels['label5'] = 'Später';

$labels['tb_label_options'] = 'Thunderbird Labels';
$labels['tb_label_enable_option'] = 'Aktiviere Labels';
$labels['tb_label_enable_shortcuts_option'] = 'Aktiviere Tastaturkürzel';
$labels['tb_label_button_label'] = 'Labels';
$labels['tb_label_button_title'] = 'Nachricht Label`n';
$labels['tb_label_contextmenu_title'] = 'Labels';
$labels['tb_label_style_option'] = "UI Style für Labels";
$labels['tb_label_label'] = "Label";

$messages = array();
