<?php
/**
* Author:
* Lluís Forns Puigmartí
*/

$labels = array();
$labels['label'] = 'Etiquetes';
$labels['label0'] = 'Cap etiqueta';
$labels['label1'] = 'Important';
$labels['label2'] = 'Feina';
$labels['label3'] = 'Personal';
$labels['label4'] = 'Per fer';
$labels['label5'] = 'Més tard';

$messages = array();
