<?php
/**
* Author:
* Deyan Stoykov
*/

$labels = array();
$labels['label'] = 'Thunderbird етикети';
$labels['label0'] = 'Без етикет';
$labels['label1'] = 'Важно';
$labels['label2'] = 'Работно';
$labels['label3'] = 'Лично';
$labels['label4'] = 'За изпълнение';
$labels['label5'] = 'Отложено';

$messages = array();
