<?php
/**
* Author:
* Pedro Ribeiro 
* pribeiro@net.ipl.pt
*/

$labels = array();
$labels['label'] = 'Etiquetas';
$labels['label0'] = 'Sem etiqueta';
$labels['label1'] = 'Importante';
$labels['label2'] = 'Trabalho';
$labels['label3'] = 'Pessoal';
$labels['label4'] = 'A fazer';
$labels['label5'] = 'Depois';

$labels['tb_label_options'] = 'Opções de etiquetas';
$labels['tb_label_enable_option'] = 'Usar etiquetas';
$labels['tb_label_enable_shortcuts_option'] = 'Usar atalhos de teclado';
$labels['tb_label_button_label'] = 'Etiquetas';
$labels['tb_label_button_title'] = 'Aplicar etiquetas nas mensagens';
$labels['tb_label_contextmenu_title'] = 'Etiquetas';
$labels['tb_label_style_option'] = "Estilo de etiquetas";
$labels['tb_label_label'] = "Etiqueta";

$messages = array();

