<?php

$labels = array();
$labels['label'] = 'Štítky';
$labels['label0'] = 'Žiadny štítok';
$labels['label1'] = 'Uôležité';
$labels['label2'] = 'Pracovné';
$labels['label3'] = 'Osobné';
$labels['label4'] = 'Urobiť';
$labels['label5'] = 'Neskôr';

$labels['tb_label_options'] = 'Štítky';
$labels['tb_label_enable_option'] = 'Povoliť štítky';
$labels['tb_label_enable_shortcuts_option'] = 'Povoliť klávesové skratky';
$labels['tb_label_button_label'] = 'Štítky';
$labels['tb_label_button_title'] = 'Nastavení štítků zprávy';
$labels['tb_label_contextmenu_title'] = 'Štítky';
$labels['tb_label_style_option'] = "Štýl štítkov";
$labels['tb_label_label'] = "Štítek";
$labels['thunderbird'] = "Thunderbird";
$labels['bullets'] = "Bodky";

$messages = array();
