<?php
/**
* Author:
* Samuele Tognini <samuele@samuele.netsons.org>
*/

$labels = array();
$labels['label'] = 'Etichette Thunderbird';
$labels['label0'] = 'Nessuna etichetta';
$labels['label1'] = 'Importante';
$labels['label2'] = 'Lavoro';
$labels['label3'] = 'Personale';
$labels['label4'] = 'Da fare';
$labels['label5'] = 'Piu\' tardi';

$labels['tb_label_options'] = 'Opzioni Etichette Thunderbird';
$labels['tb_label_enable_option'] = 'Abilita Etichette';
$labels['tb_label_enable_shortcuts_option'] = 'Abilita tasti rapidi';
$labels['tb_label_button_label'] = 'Etichette';
$labels['tb_label_button_title'] = 'Assegna etichette al messaggio';
$labels['tb_label_contextmenu_title'] = 'Etichette';
$labels['tb_label_style_option'] = "Stile UI per etichette";
$labels['tb_label_label'] = "Label";

$messages = array();

