<?php
/**
* Author:
* Michael Kefeder
*/

$labels = array();
$labels['label'] = 'Tags Thunderbird ';
$labels['label0'] = 'Aucun tag';
$labels['label1'] = 'Important';
$labels['label2'] = 'Travail';
$labels['label3'] = 'Personnel';
$labels['label4'] = 'A faire';
$labels['label5'] = 'Plus tard';

$labels['tb_label_options'] = 'Options Tags Thunderbird';
$labels['tb_label_enable_option'] = 'Activer les tags';
$labels['tb_label_enable_shortcuts_option'] = 'Activer les raccourcis clavier';
$labels['tb_label_button_label'] = 'Tags';
$labels['tb_label_button_title'] = 'Affecter des tags aux messages';
$labels['tb_label_contextmenu_title'] = 'Tags';
$labels['tb_label_style_option'] = 'Style graphique';
$labels['tb_label_label'] = "Tag";