#messagetoolbar a.button.tb-label,
#messagetoolbar a.buttonPas.tb-label {
  background-image: url(thunderbird_32.png);
  background-repeat: no-repeat;
  width: 32px;
  height: 32px;
  padding: 0px !important;
  margin: 0px 5px 0px 5px;
  text-indent: -5000px;
}

/* for menuitems non-active */
.toolbarmenu li a.label0
{
  color: #CCC;
}
.toolbarmenu li a.label0.active
{
  color: #333;
}
.toolbarmenu li a.label1
{
  color: #FCC;
}
.toolbarmenu li a.label2,
{
  color: #FC3;
}
.toolbarmenu li a.label3
{
  color: #3C3;
}
.toolbarmenu li a.label4
{
  color: #99F;
}
.toolbarmenu li a.label5
{
  color: #C9C;
}

/* for menuitems active */
.toolbarmenu li a.label1.active,
span.label1
{
  color: #FF0000;
}

.toolbarmenu li a.label2.active,
span.label2
{
  color: #FF9900;
}

.toolbarmenu li a.label3.active,
span.label3
{
  color: #009900;
}

.toolbarmenu li a.label4.active,
span.label4
{
  color: #3333FF;
}

.toolbarmenu li a.label5.active,
span.label5
{
  color: #993399;
}


/* dots for labels */
span.tb_label_dots {
  height: 0px;
  /* display: block;
  position: absolute; */
  right: 3px;
  top: 1.2em;
}

/* hack for firefox : doesnt display the bullets at the correct height */
/*
@-moz-document url-prefix() {
  span.tb_label_dots {
    top: -12px;
  }
}
*/
span.tb_label_dots span {
  font-size: 32px;
  vertical-align: middle;
  line-height: 0px;
}


div#labelbox {
  white-space: nowrap;
  position: absolute;
  right: 5%;
  top: 10px;
}


div#labelbox span {
    margin: 0 3px;
    padding: 2px;
    border: 1px solid black;
    border-radius: 3px;
    color: #black;
    font-weight: bold;
    font-size: 11px;
}
  
div#labelbox span.tb_label_span1 {
  background-color: #FF2200;
}

div#labelbox span.tb_label_span2 {
  background-color: #FF9900;
}

div#labelbox span.tb_label_span3 {
  background-color: #00CC00;
}

div#labelbox span.tb_label_span4 {
  background-color: #0CF;
}

div#labelbox span.tb_label_span5 {
  background-color: #FF33FF;
}  


/* Non-labeled selected message: changed to make it look "like" Thunderbird */
/*#messagelist tr.selected td
{
  color: #000000;
  background-color: #F0CB82;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td
{
  color: #FFFFFF;
  background-color: #CC3333;
}
*/
/* Non specific message : changed to make it look like Thunderbird */
/*#messagelist tr.selected td a
{
  color: #000000;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td a
{
  color: #FFFFFF;
}
*/
.badge {
    display: inline-block;
    padding: 0.25em 0.4em;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: 0.25rem;
    transition: color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;
}

span.tb_label_dots {
	margin: 3px 1.1em 1.5em 1.4em;
	clear: both;
	display: block;
}

span.tb_label_dots span.tb_label_badges {
	font-size: 11px;
	line-height: 11px !important;
	color: #fff;
	margin-right: 8px;
	margin-bottom: 3px;
	margin-top: -2px;
	background-color: #c9c9c9;
}
.tb_label_badges.label1 {
	background-color: #ff0000 !important;
}

.tb_label_badges.label2 {
	background-color: #ff9900 !important;
}

.tb_label_badges.label3 {
	background-color: #009900 !important;
}

.tb_label_badges.label4 {
	background-color: #3333ff !important;
}

.tb_label_badges.label5 {
	background-color: #993399 !important;
}