<?php
/**
* Author:
* Daniel P. 
*/

$labels = array();
$labels['label'] = 'Thunderbird Cimkék';
$labels['label0'] = 'Minden cimke törlése';
$labels['label1'] = 'Fontos';
$labels['label2'] = 'Munka';
$labels['label3'] = 'Személyes';
$labels['label4'] = 'Teendők';
$labels['label5'] = 'Később';

$labels['tb_label_options'] = 'Thunderbird Címke Beállítások';
$labels['tb_label_enable_option'] = 'Címkék engedélyezése';
$labels['tb_label_enable_shortcuts_option'] = 'Gyorsbillentyűk engedélyezése';
$labels['tb_label_button_label'] = 'Címkék';
$labels['tb_label_button_title'] = 'Címkék beállítása üzeneteken';
$labels['tb_label_contextmenu_title'] = 'Címkék';
$labels['tb_label_style_option'] = "Megjelenítési beállítás";
$labels['tb_label_label'] = "Címke";

$messages = array();

