<?php
/**
* Author:
* Michael Kefeder
*/
$labels = array();
$labels['label'] = 'Ετικέτες';
$labels['label0'] = 'Χωρίς Ετικέτα';
$labels['label1'] = 'Σημαντικά';
$labels['label2'] = 'Εργασίες';
$labels['label3'] = 'Προσωπικά';
$labels['label4'] = 'Εκκρεμότητες';
$labels['label5'] = 'Για αργότερα';
$labels['tb_label_options'] = 'Επιλογές Ετικετών';
$labels['tb_label_enable_option'] = 'Ενεργοποίηση ετικετών';
$labels['tb_label_enable_shortcuts_option'] = 'Ενεργοποίηση συντομεύσεων πληκτρολογίου';
$labels['tb_label_button_label'] = 'Ετικέτες';
$labels['tb_label_button_title'] = 'Τοποθέτηση ετικετών στα μηνύματα';
$labels['tb_label_contextmenu_title'] = 'Ετικέτες';
$labels['tb_label_style_option'] = "UI στυλ για ετικέτες";
$labels['tb_label_label'] = "Ετικέτα";
$messages = array();
