<?php
/**
* Author:
* Николай Николай
*/

$labels = array();
$labels['label'] = 'Метка Thunderbird';
$labels['label0'] = 'Удалить все метки';
$labels['label1'] = 'Важное';
$labels['label2'] = 'Рабочее';
$labels['label3'] = 'Личное';
$labels['label4'] = 'К исполнению';
$labels['label5'] = 'Отложено';

$labels['tb_label_options'] = 'Метки Thunderbird';
$labels['tb_label_enable_option'] = 'Включить метки';
$labels['tb_label_enable_shortcuts_option'] = 'Включить горячие клавиши';
$labels['tb_label_button_label'] = 'Метки';
$labels['tb_label_button_title'] = 'Присвоить сообщению метку';
$labels['tb_label_contextmenu_title'] = 'Метки';
$labels['tb_label_style_option'] = "Стиль меток";
$labels['tb_label_label'] = "Метка";

$messages = array();

