<?php
/**
* Author:
* Mykyta Solomko
*/

$labels = array();
$labels['label'] = 'Мітки Thunderbird';
$labels['label0'] = 'Без мітки';
$labels['label1'] = 'Важливе';
$labels['label2'] = 'Робоче';
$labels['label3'] = 'Особисте';
$labels['label4'] = 'До виконання';
$labels['label5'] = 'Відсунуте';

$labels['tb_label_options'] = 'Налаштування міток Thunderbird';
$labels['tb_label_enable_option'] = 'Ввімкнути мітки';
$labels['tb_label_enable_shortcuts_option'] = 'Клавіатурні скорочння';
$labels['tb_label_button_label'] = 'Мітки';
$labels['tb_label_button_title'] = 'Встановити мітки на повідомленнях';
$labels['tb_label_contextmenu_title'] = 'Мітки';
$labels['tb_label_style_option'] = "Стиль інтерфейсу міток";
$labels['tb_label_label'] = "Мітка";

$messages = array();

