<?php

$labels = array();
$labels['label'] = 'Štítky';
$labels['label0'] = 'Žádný štítek';
$labels['label1'] = 'Důležité';
$labels['label2'] = 'Pracovní';
$labels['label3'] = 'Osobní';
$labels['label4'] = 'Udělat';
$labels['label5'] = 'Později';

$labels['tb_label_options'] = 'Štítky';
$labels['tb_label_enable_option'] = 'Povolit štítky';
$labels['tb_label_enable_shortcuts_option'] = 'Povolit klávesové zkratky';
$labels['tb_label_button_label'] = 'Štítky';
$labels['tb_label_button_title'] = 'Nastavení štítků zprávy';
$labels['tb_label_contextmenu_title'] = 'Štítky';
$labels['tb_label_style_option'] = "Styl štítků";
$labels['tb_label_label'] = "Štítek";
$labels['thunderbird'] = "Thunderbird";
$labels['bullets'] = "Tečky";

$messages = array();

