<?php
/**
* Author:
* master771
*/

$labels = array();
$labels['label'] = 'Etykiety';
$labels['label0'] = 'Brak';
$labels['label1'] = 'Ważne';
$labels['label2'] = 'Praca';
$labels['label3'] = 'Osobiste';
$labels['label4'] = 'Do zrobienia';
$labels['label5'] = 'Później';

$labels['tb_label_options'] = 'Opcje etykiet';
$labels['tb_label_enable_option'] = 'Włącz etykiety';
$labels['tb_label_enable_shortcuts_option'] = 'Włącz skróty klawiaturowe';
$labels['tb_label_button_label'] = 'Etykiety';
$labels['tb_label_button_title'] = 'Ustaw etykiety dla wiadomości';
$labels['tb_label_contextmenu_title'] = 'Etykiety';
$labels['tb_label_style_option'] = 'Wygląd etykiet';
$labels['tb_label_label'] = 'Etykieta';

$messages = array();

